# MyPackage

MyPackage is a Python package that provides a function to copy a file to the current location.

## Installation

You can install MyPackage using `pip`:
pip install cellebrite_report

## Usage


```python
```